@@ -51,7 +51,7 @@
       (fg-shadow-subtle "#675462")
 
       (bg-neutral "#d7c9d0")
-      (fg-neutral "#5a4c5f")
+      (fg-neutral "#4e4053")
 
       (bg-shadow-intense "#cc95b7")
       (fg-shadow-intense "#683455")
