@@ -51,7 +51,7 @@
       (fg-shadow-subtle "#a2a0b2")
 
       (bg-neutral "#43404c")
-      (fg-neutral "#aeabbc")
+      (fg-neutral "#c5c7d4")
 
       (bg-shadow-intense "#50447f")
       (fg-shadow-intense "#cfcff8")
