@@ -51,7 +51,7 @@
       (fg-shadow-subtle "#afa497")
 
       (bg-neutral "#4f4542")
-      (fg-neutral "#bfb4a7")
+      (fg-neutral "#d9cfbe")
 
       (bg-shadow-intense "#601a2f")
       (fg-shadow-intense "#e2b0a4")
