@@ -1,11 +1,11 @@
-;;; doric-themes.el --- Minimalist themes -*- lexical-binding:t -*-
+;;; doric-themes.el --- Highly legible minimalist themes with precise typography -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2025  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/doric-themes
-;; Version: 0.1.0
+;; Version: 0.2.0
 ;; Package-Requires: ((emacs "29.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -58,11 +58,10 @@
   (append doric-themes-light-themes doric-themes-dark-themes)
   "Symbols of all the Doric themes.")
 
-(defgroup doric-themes ()
-  "Minimalist themes with few colours and precise typography."
+(defgroup doric-themes nil
+  "Highly legible minimalist themes with precise typography."
   :group 'faces
-  :prefix "doric-themes-"
-  :tag "Doric Themes")
+  :link '(url-link :tag "Sample pictures" "https://protesilaos.com/emacs/doric-themes-pictures"))
 
 ;;;; User options
 
@@ -259,18 +258,17 @@ respectively."
         (delete current-theme themes)
       themes)))
 
-(defvar doric-themes-subset-history nil
-  "Minibuffer history for `doric-themes-subset-prompt'.")
+(make-obsolete-variable 'doric-themes-subset-history nil "0.2.0")
 
 (defun doric-themes-subset-prompt ()
   "Select `dark' or `light' and return it as a symbol."
-  (let ((default (car doric-themes-subset-history)))
-    (intern
-     (completing-read
-      (format-prompt "Select variant" default)
-      '("dark" "light")
-      nil :require-match nil
-      doric-themes-subset-history default))))
+  (intern
+   (cadr
+    (read-multiple-choice
+     "Variant"
+     '((?d "dark" "Load a random dark theme")
+       (?l "light" "Load a random light theme"))
+     "Limit to the dark or light subset of the Ef themes collection."))))
 
 ;;;###autoload
 (defun doric-themes-load-random (&optional variant)
@@ -320,7 +318,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     org-dispatcher-highlight
     proced-marked
     pulse-highlight-start-face
-    read-multiple-choice-face
     rectangle-preview
     speedbar-highlight-face
     tab-bar-tab-highlight
@@ -346,7 +343,10 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     substitute-match))
 
 (defconst doric-themes-intense-shadow-foreground-only-faces
-  '(calendar-month-header
+  '(all-the-icons-completion-dir-face
+    all-the-icons-dired-dir-face
+    all-the-icons-ibuffer-dir-face
+    calendar-month-header
     change-log-date
     denote-faces-date
     denote-faces-day
@@ -369,12 +369,16 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     magit-log-author
     magit-log-date
     marginalia-date
+    nerd-icons-completion-dir-face
+    nerd-icons-dired-dir-face
+    nerd-icons-ibuffer-dir-face
     notmuch-search-date
     org-agenda-calendar-daterange
     org-agenda-column-dateline
     org-date
     org-sexp-date
     proced-time-colon
+    rcirc-timestamp
     vc-state-base
     vc-up-to-date-state
     ztreep-diff-header-small-face))
@@ -429,13 +433,11 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 (defconst doric-themes-subtle-shadow-foreground-only-faces
   '(all-the-icons-blue
     all-the-icons-blue-alt
-    all-the-icons-completion-dir-face
     all-the-icons-cyan
     all-the-icons-cyan-alt
     all-the-icons-dblue
     all-the-icons-dcyan
     all-the-icons-dgreen
-    all-the-icons-dired-dir-face
     all-the-icons-dmaroon
     all-the-icons-dorange
     all-the-icons-dpink
@@ -444,6 +446,9 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     all-the-icons-dsilver
     all-the-icons-dyellow
     all-the-icons-green
+    all-the-icons-ibuffer-file-face
+    all-the-icons-ibuffer-mode-face
+    all-the-icons-ibuffer-size-face
     all-the-icons-lblue
     all-the-icons-lcyan
     all-the-icons-lgreen
@@ -464,6 +469,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     all-the-icons-silver
     all-the-icons-yellow
     avy-background-face
+    aw-background-face
     breadcrumb-face
     calendar-weekend-header
     change-log-email
@@ -538,6 +544,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     marginalia-type
     marginalia-value
     marginalia-version
+    markdown-metadata-key-face
     message-header-mml
     message-header-name
     message-header-newsgroups
@@ -545,13 +552,11 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     mu4e-header-face
     nerd-icons-blue
     nerd-icons-blue-alt
-    nerd-icons-completion-dir-face
     nerd-icons-cyan
     nerd-icons-cyan-alt
     nerd-icons-dblue
     nerd-icons-dcyan
     nerd-icons-dgreen
-    nerd-icons-dired-dir-face
     nerd-icons-dmaroon
     nerd-icons-dorange
     nerd-icons-dpink
@@ -560,6 +565,9 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     nerd-icons-dsilver
     nerd-icons-dyellow
     nerd-icons-green
+    nerd-icons-ibuffer-file-face
+    nerd-icons-ibuffer-mode-face
+    nerd-icons-ibuffer-size-face
     nerd-icons-lblue
     nerd-icons-lcyan
     nerd-icons-lgreen
@@ -593,9 +601,9 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     org-done
     org-headline-done
     org-scheduled
-    org-scheduled-previously
     org-scheduled-today
     org-special-keyword
+    org-tag
     org-time-grid
     org-upcoming-deadline
     org-upcoming-distant-deadline
@@ -648,9 +656,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-search-matching-authors
     notmuch-tree-match-author-face
     notmuch-search-flagged-face
-    org-imminent-deadline
     org-headline-todo
-    org-table-header
     org-table-row
     org-todo
     org-warning
@@ -665,6 +671,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     which-key-command-description-face
     widget-button
     widget-button-pressed
+    woman-addition
     ztreep-node-face))
 
 (defconst doric-themes-main-foreground-only-faces
@@ -674,7 +681,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     breadcrumb-project-crumbs-face
     c-annotation-face
     change-log-function
-    change-log-list
     child-frame-border
     consult-bookmark
     consult-buffer
@@ -682,6 +688,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     denote-faces-prompt-current-name
     denote-faces-title
     diary
+    dictionary-word-definition-face
     dired-mark
     dired-perm-write
     dired-set-id
@@ -769,8 +776,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     org-inline-src-block
     org-latex-and-related
     org-mode-line-clock
-    org-quote
-    org-verse
     proced-cpu
     proced-mark
     proced-memory-low-usage
@@ -832,6 +837,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     denote-faces-keywords
     denote-faces-signature
     denote-faces-subdirectory
+    dictionary-button-face
     diff-nonexistent
     dired-header
     diredfl-dir-heading
@@ -912,6 +918,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     magit-section-heading
     magit-signature-good
     magit-tag
+    Man-overstrike
     markdown-header-face-1
     markdown-header-face-2
     markdown-header-face-3
@@ -940,6 +947,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     org-level-7
     org-level-8
     org-list-dt
+    org-table-header
     org-tag-group
     org-target
     outline-1
@@ -952,6 +960,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     outline-8
     proced-emacs-pid
     proced-sort-header
+    rcirc-prompt
+    rcirc-other-nick
     reb-regexp-grouping-backslash
     reb-regexp-grouping-construct
     sh-escaped-newline
@@ -981,6 +991,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     vc-needs-update-state
     vc-removed-state
     which-func
+    woman-bold
     world-clock-label
     xref-file-header
     ztreep-diff-header-face
@@ -990,6 +1001,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
   '(appt-notification
     aw-key-face
     change-log-conditionals
+    change-log-list
     comint-highlight-input
     compilation-error
     completions-group-title
@@ -1000,6 +1012,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     css-selector
     custom-changed
     custom-invalid
+    dictionary-word-entry-face
     diff-error
     diff-file-header
     diff-hunk-header
@@ -1033,6 +1046,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     proced-memory-high-usage
     proced-run-status-code
     proced-uninterruptible-sleep-status-code
+    rcirc-bright-nick
+    rcirc-track-keyword
     smerge-markers
     tab-line-tab-modified
     transient-key
@@ -1041,8 +1056,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     transient-key-return
     transient-key-stack
     transient-key-stay
-    vertico-group-title
-    which-key-key-face))
+    vertico-group-title))
 
 (defconst doric-themes-italic-faces
   '(Info-quoted
@@ -1127,14 +1141,12 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-wash-cited-text
     org-agenda-calendar-event
     org-agenda-calendar-sexp
-    org-code
     org-inline-src-block
     org-latex-and-related
     org-macro
     org-priority
-    org-tag
-    org-verbatim
     package-description
+    rcirc-dim-nick
     sh-heredoc
     shr-code
     speedbar-tag-face
@@ -1146,11 +1158,11 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     which-key-docstring-face
     which-key-group-description-face
     which-key-local-map-description-face
+    woman-italic
     ztreep-node-count-children-face))
 
 (defconst doric-themes-underline-emphasis-faces
-  '(aw-leading-char-face
-    company-echo-common
+  '(company-echo-common
     company-preview-common
     company-preview-search
     company-tooltip-common
@@ -1163,12 +1175,17 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     font-latex-underline-face
     gnus-emphasis-highlight-words
     lazy-highlight
+    Man-underline
     notmuch-tag-added
     orderless-match-face-0
     orderless-match-face-1
     orderless-match-face-2
     orderless-match-face-3
     proced-session-leader-pid
+    rcirc-my-nick
+    rcirc-nick-in-message
+    rcirc-nick-in-message-full-line
+    rcirc-track-nick
     show-paren-mismatch
     speedbar-selected-face
     transient-argument
@@ -1180,6 +1197,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     custom-link
     denote-faces-link
     denote-faces-query-link
+    dictionary-reference-face
     dired-symlink
     diredfl-symlink
     eshell-ls-symlink
@@ -1194,6 +1212,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     org-footnote
     org-link
     package-name
+    rcirc-url
     shr-link))
 
 (defconst doric-themes-diff-added-faces
@@ -1202,6 +1221,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     diff-indicator-added
     ediff-current-diff-B
     magit-diff-added
+    magit-diff-added-highlight
     magit-diffstat-added
     smerge-lower
     ztreep-diff-model-add-face))
@@ -1209,7 +1229,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 (defconst doric-themes-diff-added-refine-faces
   '(diff-refine-added
     ediff-fine-diff-B
-    magit-diff-added-highlight
     smerge-refined-added))
 
 (defconst doric-themes-diff-changed-faces
@@ -1218,12 +1237,12 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     diff-indicator-changed
     ediff-current-diff-C
     magit-diff-base
+    magit-diff-base-highlight
     smerge-base))
 
 (defconst doric-themes-diff-changed-refine-faces
   '(diff-refine-changed
     ediff-fine-diff-C
-    magit-diff-base-highlight
     smerge-refined-changed))
 
 (defconst doric-themes-diff-removed-faces
@@ -1232,6 +1251,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     diff-indicator-removed
     ediff-current-diff-A
     magit-diff-removed
+    magit-diff-removed-highlight
     magit-diffstat-removed
     smerge-upper
     ztreep-diff-model-diff-face))
@@ -1239,7 +1259,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 (defconst doric-themes-diff-removed-refine-faces
   '(diff-refine-removed
     ediff-fine-diff-A
-    magit-diff-removed-highlight
     smerge-refined-removed))
 
 (defconst doric-themes-error-foreground-only-faces
@@ -1299,7 +1318,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(tty-menu-disabled-face ((t :background ,bg-accent :foreground ,fg-shadow-subtle)))
             `(tty-menu-enabled-face ((t :background ,bg-accent :foreground ,fg-main)))
             `(tty-menu-selected-face ((t :background ,fg-main :foreground ,bg-main)))
-
+            `(read-multiple-choice-face ((t :inherit bold-italic :background ,fg-shadow-intense :foreground ,bg-main)))
 
             '(adoc-meta-face ((t :inherit fixed-pitch)))
             '(adoc-meta-hide-face ((t :inherit fixed-pitch)))
@@ -1323,6 +1342,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(ansi-color-bright-cyan ((t :background ,fg-faint-cyan :foreground ,fg-faint-cyan)))
             `(ansi-color-cyan ((t :background ,fg-faint-cyan :foreground ,fg-faint-cyan)))
 
+            `(aw-leading-char-face ((t :inherit bold-italic :height 1.5 :foreground ,fg-accent)))
+
             `(company-tooltip ((t :inherit fixed-pitch :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
 
             `(corfu-default ((t :inherit fixed-pitch :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
@@ -1363,6 +1384,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             ,@(doric-themes-prepare-faces doric-themes-diff-removed-faces :background ''unspecified :foreground 'fg-faint-red)
             ,@(doric-themes-prepare-faces doric-themes-diff-removed-refine-faces :inherit ''bold :background ''unspecified :foreground 'fg-faint-red)
 
+            '(embark-keybinding ((t :inherit (fixed-pitch bold-italic))))
+
             `(font-lock-comment-delimiter-face ((t :inherit italic :foreground ,fg-accent)))
             `(font-lock-comment-face ((t :inherit italic :foreground ,fg-accent)))
             `(font-lock-variable-name-face  ((t :inherit italic)))
@@ -1424,6 +1447,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(query-replace ((t :inherit isearch)))
 
             '(help-key-binding ((t :inherit (fixed-pitch bold-italic))))
+
             '(line-number-current-line ((t :inherit (highlight bold))))
 
             `(keycast-key ((t :inherit bold-italic :background ,fg-shadow-intense :foreground ,bg-main)))
@@ -1460,6 +1484,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(org-block-begin-line ((t :inherit fixed-pitch :background ,bg-neutral :foreground ,fg-neutral :extend t)))
             `(org-block-end-line ((t :inherit org-block-begin-line)))
             '(org-checkbox ((t :inherit fixed-pitch)))
+            `(org-code ((t :inherit (fixed-pitch italic) :foreground ,fg-shadow-subtle)))
             `(org-column-title ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             `(org-date-selected
               ((default :background ,bg-accent :foreground ,fg-main)
@@ -1470,16 +1495,29 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(org-ellipsis (( ))) ; inherits from the heading's color
             '(org-formula ((t :inherit fixed-pitch)))
             `(org-hide ((t :foreground ,bg-main)))
+            `(org-imminent-deadline ((t :inherit bold :foreground ,fg-accent)))
             `(org-indent ((t :inherit (fixed-pitch org-hide))))
             `(org-meta-line ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             '(org-property-value ((t :inherit fixed-pitch)))
+            '(org-quote ((t :inherit org-block)))
+            `(org-scheduled-previously ((t :inherit bold :foreground ,fg-shadow-subtle)))
+            `(org-verbatim ((t :inherit (fixed-pitch italic) :foreground ,fg-shadow-subtle)))
+            '(org-verse ((t :inherit org-block)))
             `(org-table ((t :inherit fixed-pitch :foreground ,fg-accent)))
 
+            `(package-mark-delete-line ((t :inherit bold-italic :background ,bg-shadow-intense :foreground ,fg-main)))
+            `(package-mark-install-line ((t :inherit bold-italic :background ,bg-accent :foreground ,fg-main)))
+
+            '(rcirc-monospace-text ((t :inherit fixed-pitch)))
+            '(rcirc-server ((t :inherit font-lock-comment-face)))
+
             `(reb-match-0 ((t :background ,bg-accent :foreground ,fg-main)))
             `(reb-match-1 ((t :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
             `(reb-match-2 ((t :background ,bg-accent :foreground ,fg-accent)))
             `(reb-match-3 ((t :background ,bg-shadow-intense :foreground ,fg-shadow-intense)))
 
+            `(spacious-padding-line-active ((t :foreground ,fg-accent)))
+            `(spacious-padding-line-inactive ((t :foreground ,bg-accent)))
             `(spacious-padding-subtle-mode-line-active ((t :foreground ,fg-accent)))
             `(spacious-padding-subtle-mode-line-inactive ((t :foreground ,bg-accent)))
 
@@ -1494,11 +1532,15 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             '(telega-webpage-fixed ((t :inherit fixed-pitch)))
             '(telega-webpage-preformatted ((t :inherit fixed-pitch)))
 
+            '(textsec-suspicious (( )))
+
             `(vc-edited-state ((t :inherit italic)))
             `(vc-locally-added-state ((t :inherit italic)))
 
             '(vtable ((t :inherit fixed-pitch)))
 
+            '(which-key-key-face ((t :inherit (fixed-pitch bold-italic))))
+
             `(whitespace-big-indent ((t :foreground ,bg-shadow-intense)))
             `(whitespace-empty ((t :foreground ,bg-shadow-intense)))
             `(whitespace-hspace ((t :foreground ,bg-shadow-intense)))
